@@ -5,9 +5,9 @@ from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 
-from domain.distribution.distribution_cell_value_types import DistributionCellValueType
-from domain.distribution.distribution_data import DistributionData
-from domain.distribution.distribution_image import DistributionImage
+from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
+from xlsx_lib.domain.distribution.distribution_data import DistributionData
+from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
 from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
