@@ -5,9 +5,9 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
-from domain.distribution.distribution_data import DistributionData
-from domain.distribution.distribution_image import DistributionImage
-from domain.distribution.distribution_sheet import DistributionSheet
+from xlsx_lib.domain.distribution.distribution_data import DistributionData
+from xlsx_lib.domain.distribution.distribution_image import DistributionImage
+from xlsx_lib.domain.distribution.distribution_sheet import DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
